@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009,2010, Roger Light <roger@atchoo.org>
+Copyright (c) 2009-2011 Roger Light <roger@atchoo.org>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -27,22 +27,60 @@ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include <assert.h>
 #include <string.h>
 #include <time.h>
 
 #include <mosquitto.h>
+#include <memory_mosq.h>
 #include <net_mosq.h>
 #include <send_mosq.h>
 #include <util_mosq.h>
 
+int _mosquitto_packet_alloc(struct _mosquitto_packet *packet)
+{
+	uint8_t remaining_bytes[5], byte;
+	uint32_t remaining_length;
+	int i;
+
+	assert(packet);
+
+	remaining_length = packet->remaining_length;
+	packet->payload = NULL;
+	packet->remaining_count = 0;
+	do{
+		byte = remaining_length % 128;
+		remaining_length = remaining_length / 128;
+		/* If there are more digits to encode, set the top bit of this digit */
+		if(remaining_length > 0){
+			byte = byte | 0x80;
+		}
+		remaining_bytes[packet->remaining_count] = byte;
+		packet->remaining_count++;
+	}while(remaining_length > 0 && packet->remaining_count < 5);
+	if(packet->remaining_count == 5) return MOSQ_ERR_PAYLOAD_SIZE;
+	packet->packet_length = packet->remaining_length + 1 + packet->remaining_count;
+	packet->payload = _mosquitto_malloc(sizeof(uint8_t)*packet->packet_length);
+	if(!packet->payload) return MOSQ_ERR_NOMEM;
+
+	packet->payload[0] = packet->command;
+	for(i=0; i<packet->remaining_count; i++){
+		packet->payload[i+1] = remaining_bytes[i];
+	}
+	packet->pos = 1 + packet->remaining_count;
+
+	return MOSQ_ERR_SUCCESS;
+}
+
 #ifndef WITH_BROKER
 void _mosquitto_check_keepalive(struct mosquitto *mosq)
 {
-	if(mosq && mosq->sock != -1 && time(NULL) - mosq->last_msg_out >= mosq->keepalive){
-		if(mosq->state == mosq_cs_connected){
+	assert(mosq);
+	if(mosq->core.sock != INVALID_SOCKET && time(NULL) - mosq->core.last_msg_out >= mosq->core.keepalive){
+		if(mosq->core.state == mosq_cs_connected){
 			_mosquitto_send_pingreq(mosq);
 		}else{
-			_mosquitto_socket_close(mosq);
+			_mosquitto_socket_close(&mosq->core);
 		}
 	}
 }
@@ -56,12 +94,13 @@ int _mosquitto_fix_sub_topic(char **subtopic)
 	char *fixed = NULL;
 	char *token;
 
-	if(!subtopic || !(*subtopic)) return 1;
+	assert(subtopic);
+	assert(*subtopic);
 
 	/* size of fixed here is +1 for the terminating 0 and +1 for the spurious /
 	 * that gets appended. */
-	fixed = calloc(strlen(*subtopic)+2, 1);
-	if(!fixed) return 1;
+	fixed = _mosquitto_calloc(strlen(*subtopic)+2, 1);
+	if(!fixed) return MOSQ_ERR_NOMEM;
 
 	if((*subtopic)[0] == '/'){
 		fixed[0] = '/';
@@ -74,17 +113,17 @@ int _mosquitto_fix_sub_topic(char **subtopic)
 	}
 
 	fixed[strlen(fixed)-1] = '\0';
-	free(*subtopic);
+	_mosquitto_free(*subtopic);
 	*subtopic = fixed;
-	return 0;
+	return MOSQ_ERR_SUCCESS;
 }
 
-uint16_t _mosquitto_mid_generate(struct mosquitto *mosq)
+uint16_t _mosquitto_mid_generate(struct _mosquitto_core *core)
 {
-	if(!mosq) return 1;
+	assert(core);
 
-	mosq->last_mid++;
-	if(mosq->last_mid == 0) mosq->last_mid++;
+	core->last_mid++;
+	if(core->last_mid == 0) core->last_mid++;
 	
-	return mosq->last_mid;
+	return core->last_mid;
 }
