@@ -28,13 +28,10 @@ POSSIBILITY OF SUCH DAMAGE.
 */
 
 #include <assert.h>
-#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 
-#ifndef CMAKE
 #include <config.h>
-#endif
 
 #include <net_mosq.h>
 #include <mqtt3.h>
